@@ -14,6 +14,7 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 # Copyright (c) OWASP Foundation. All Rights Reserved.
+
 import re
 from enum import Enum
 from os.path import exists
@@ -25,7 +26,7 @@ import serializable
 from packageurl import PackageURL
 from sortedcontainers import SortedSet
 
-from .._internal.compare import ComparableTuple as _ComparableTuple
+from .._internal.compare import ComparablePackageURL as _ComparablePackageURL, ComparableTuple as _ComparableTuple
 from .._internal.hash import file_sha1sum as _file_sha1sum
 from ..exception.model import InvalidOmniBorIdException, InvalidSwhidException, NoPropertiesProvidedException
 from ..exception.serialization import (
@@ -42,7 +43,7 @@ from ..schema.schema import (
     SchemaVersion1Dot5,
     SchemaVersion1Dot6,
 )
-from ..serialization import BomRefHelper, LicenseRepositoryHelper, PackageUrl
+from ..serialization import BomRefHelper, LicenseRepositoryHelper, PackageUrl as PackageUrlSH
 from . import (
     AttachedText,
     Copyright,
@@ -72,9 +73,14 @@ class Commit:
         See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.4/xml/#type_commitType
     """
 
-    def __init__(self, *, uid: Optional[str] = None, url: Optional[XsUri] = None,
-                 author: Optional[IdentifiableAction] = None, committer: Optional[IdentifiableAction] = None,
-                 message: Optional[str] = None) -> None:
+    def __init__(
+        self, *,
+        uid: Optional[str] = None,
+        url: Optional[XsUri] = None,
+        author: Optional[IdentifiableAction] = None,
+        committer: Optional[IdentifiableAction] = None,
+        message: Optional[str] = None,
+    ) -> None:
         if not uid and not url and not author and not committer and not message:
             raise NoPropertiesProvidedException(
                 'At least one of `uid`, `url`, `author`, `committer` or `message` must be provided for a `Commit`.'
@@ -194,8 +200,11 @@ class ComponentEvidence:
         See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.4/xml/#type_componentEvidenceType
     """
 
-    def __init__(self, *, licenses: Optional[Iterable[License]] = None,
-                 copyright: Optional[Iterable[Copyright]] = None) -> None:
+    def __init__(
+        self, *,
+        licenses: Optional[Iterable[License]] = None,
+        copyright: Optional[Iterable[Copyright]] = None,
+    ) -> None:
         if not licenses and not copyright:
             raise NoPropertiesProvidedException(
                 'At least one of `licenses` or `copyright` must be supplied for a `ComponentEvidence`.'
@@ -425,7 +434,11 @@ class Diff:
         See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.4/xml/#type_diffType
     """
 
-    def __init__(self, *, text: Optional[AttachedText] = None, url: Optional[XsUri] = None) -> None:
+    def __init__(
+        self, *,
+        text: Optional[AttachedText] = None,
+        url: Optional[XsUri] = None,
+    ) -> None:
         if not text and not url:
             raise NoPropertiesProvidedException(
                 'At least one of `text` or `url` must be provided for a `Diff`.'
@@ -506,8 +519,12 @@ class Patch:
         See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.4/xml/#type_patchType
     """
 
-    def __init__(self, *, type: PatchClassification, diff: Optional[Diff] = None,
-                 resolves: Optional[Iterable[IssueType]] = None) -> None:
+    def __init__(
+        self, *,
+        type: PatchClassification,
+        diff: Optional[Diff] = None,
+        resolves: Optional[Iterable[IssueType]] = None,
+    ) -> None:
         self.type = type
         self.diff = diff
         self.resolves = resolves or []  # type:ignore[assignment]
@@ -595,10 +612,15 @@ class Pedigree:
         See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.4/xml/#type_pedigreeType
     """
 
-    def __init__(self, *, ancestors: Optional[Iterable['Component']] = None,
-                 descendants: Optional[Iterable['Component']] = None, variants: Optional[Iterable['Component']] = None,
-                 commits: Optional[Iterable[Commit]] = None, patches: Optional[Iterable[Patch]] = None,
-                 notes: Optional[str] = None) -> None:
+    def __init__(
+        self, *,
+        ancestors: Optional[Iterable['Component']] = None,
+        descendants: Optional[Iterable['Component']] = None,
+        variants: Optional[Iterable['Component']] = None,
+        commits: Optional[Iterable[Commit]] = None,
+        patches: Optional[Iterable[Patch]] = None,
+        notes: Optional[str] = None,
+    ) -> None:
         if not ancestors and not descendants and not variants and not commits and not patches and not notes:
             raise NoPropertiesProvidedException(
                 'At least one of `ancestors`, `descendants`, `variants`, `commits`, `patches` or `notes` must be '
@@ -747,9 +769,16 @@ class Swid:
         See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.4/xml/#type_swidType
     """
 
-    def __init__(self, *, tag_id: str, name: str, version: Optional[str] = None,
-                 tag_version: Optional[int] = None, patch: Optional[bool] = None,
-                 text: Optional[AttachedText] = None, url: Optional[XsUri] = None) -> None:
+    def __init__(
+        self, *,
+        tag_id: str,
+        name: str,
+        version: Optional[str] = None,
+        tag_version: Optional[int] = None,
+        patch: Optional[bool] = None,
+        text: Optional[AttachedText] = None,
+        url: Optional[XsUri] = None,
+    ) -> None:
         self.tag_id = tag_id
         self.name = name
         self.version = version
@@ -1030,25 +1059,40 @@ class Component(Dependable):
             )
         )
 
-    def __init__(self, *,
-                 name: str, type: ComponentType = ComponentType.LIBRARY,
-                 mime_type: Optional[str] = None, bom_ref: Optional[Union[str, BomRef]] = None,
-                 supplier: Optional[OrganizationalEntity] = None,
-                 publisher: Optional[str] = None, group: Optional[str] = None, version: Optional[str] = None,
-                 description: Optional[str] = None, scope: Optional[ComponentScope] = None,
-                 hashes: Optional[Iterable[HashType]] = None, licenses: Optional[Iterable[License]] = None,
-                 copyright: Optional[str] = None, purl: Optional[PackageURL] = None,
-                 external_references: Optional[Iterable[ExternalReference]] = None,
-                 properties: Optional[Iterable[Property]] = None, release_notes: Optional[ReleaseNotes] = None,
-                 cpe: Optional[str] = None, swid: Optional[Swid] = None, pedigree: Optional[Pedigree] = None,
-                 components: Optional[Iterable['Component']] = None, evidence: Optional[ComponentEvidence] = None,
-                 modified: bool = False, manufacturer: Optional[OrganizationalEntity] = None,
-                 authors: Optional[Iterable[OrganizationalContact]] = None,
-                 omnibor_ids: Optional[Iterable[OmniborId]] = None, swhids: Optional[Iterable[Swhid]] = None,
-                 crypto_properties: Optional[CryptoProperties] = None, tags: Optional[Iterable[str]] = None,
-                 # Deprecated in v1.6
-                 author: Optional[str] = None,
-                 ) -> None:
+    def __init__(
+        self, *,
+        name: str,
+        type: ComponentType = ComponentType.LIBRARY,
+        mime_type: Optional[str] = None,
+        bom_ref: Optional[Union[str, BomRef]] = None,
+        supplier: Optional[OrganizationalEntity] = None,
+        publisher: Optional[str] = None,
+        group: Optional[str] = None,
+        version: Optional[str] = None,
+        description: Optional[str] = None,
+        scope: Optional[ComponentScope] = None,
+        hashes: Optional[Iterable[HashType]] = None,
+        licenses: Optional[Iterable[License]] = None,
+        copyright: Optional[str] = None,
+        purl: Optional[PackageURL] = None,
+        external_references: Optional[Iterable[ExternalReference]] = None,
+        properties: Optional[Iterable[Property]] = None,
+        release_notes: Optional[ReleaseNotes] = None,
+        cpe: Optional[str] = None,
+        swid: Optional[Swid] = None,
+        pedigree: Optional[Pedigree] = None,
+        components: Optional[Iterable['Component']] = None,
+        evidence: Optional[ComponentEvidence] = None,
+        modified: bool = False,
+        manufacturer: Optional[OrganizationalEntity] = None,
+        authors: Optional[Iterable[OrganizationalContact]] = None,
+        omnibor_ids: Optional[Iterable[OmniborId]] = None,
+        swhids: Optional[Iterable[Swhid]] = None,
+        crypto_properties: Optional[CryptoProperties] = None,
+        tags: Optional[Iterable[str]] = None,
+        # Deprecated in v1.6
+        author: Optional[str] = None,
+    ) -> None:
         self.type = type
         self.mime_type = mime_type
         if isinstance(bom_ref, BomRef):
@@ -1406,7 +1450,7 @@ class Component(Dependable):
         self._cpe = cpe
 
     @property
-    @serializable.type_mapping(PackageUrl)
+    @serializable.type_mapping(PackageUrlSH)
     @serializable.xml_sequence(15)
     def purl(self) -> Optional[PackageURL]:
         """
@@ -1699,19 +1743,42 @@ class Component(Dependable):
     def __lt__(self, other: Any) -> bool:
         if isinstance(other, Component):
             return _ComparableTuple((
-                self.type, self.group, self.name, self.version
+                self.type, self.group, self.name, self.version,
+                self.mime_type, self.supplier, self.author, self.publisher,
+                self.description, self.scope, _ComparableTuple(self.hashes),
+                _ComparableTuple(self.licenses), self.copyright, self.cpe,
+                None if self.purl is None else _ComparablePackageURL(self.purl),
+                self.swid, self.pedigree,
+                _ComparableTuple(self.external_references), _ComparableTuple(self.properties),
+                _ComparableTuple(self.components), self.evidence, self.release_notes, self.modified,
+                _ComparableTuple(self.authors), _ComparableTuple(self.omnibor_ids), self.manufacturer,
+                _ComparableTuple(self.swhids), self.crypto_properties, _ComparableTuple(self.tags)
             )) < _ComparableTuple((
-                other.type, other.group, other.name, other.version
+                other.type, other.group, other.name, other.version,
+                other.mime_type, other.supplier, other.author, other.publisher,
+                other.description, other.scope, _ComparableTuple(other.hashes),
+                _ComparableTuple(other.licenses), other.copyright, other.cpe,
+                None if other.purl is None else _ComparablePackageURL(other.purl),
+                other.swid, other.pedigree,
+                _ComparableTuple(other.external_references), _ComparableTuple(other.properties),
+                _ComparableTuple(other.components), other.evidence, other.release_notes, other.modified,
+                _ComparableTuple(other.authors), _ComparableTuple(other.omnibor_ids), other.manufacturer,
+                _ComparableTuple(other.swhids), other.crypto_properties, _ComparableTuple(other.tags)
             ))
         return NotImplemented
 
     def __hash__(self) -> int:
         return hash((
-            self.type, self.mime_type, self.supplier, self.author, self.publisher, self.group, self.name,
-            self.version, self.description, self.scope, tuple(self.hashes), tuple(self.licenses), self.copyright,
-            self.cpe, self.purl, self.swid, self.pedigree, tuple(self.external_references), tuple(self.properties),
-            tuple(self.components), self.evidence, self.release_notes, self.modified, tuple(self.authors),
-            tuple(self.omnibor_ids),
+            self.type, self.group, self.name, self.version,
+            self.mime_type, self.supplier, self.author, self.publisher,
+            self.description, self.scope, tuple(self.hashes),
+            tuple(self.licenses), self.copyright, self.cpe,
+            self.purl,
+            self.swid, self.pedigree,
+            tuple(self.external_references), tuple(self.properties),
+            tuple(self.components), self.evidence, self.release_notes, self.modified,
+            tuple(self.authors), tuple(self.omnibor_ids), self.manufacturer,
+            tuple(self.swhids), self.crypto_properties, tuple(self.tags)
         ))
 
     def __repr__(self) -> str:
