@@ -47,7 +47,11 @@ class IssueTypeSource:
         See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.4/xml/#type_issueType
     """
 
-    def __init__(self, *, name: Optional[str] = None, url: Optional[XsUri] = None) -> None:
+    def __init__(
+        self, *,
+        name: Optional[str] = None,
+        url: Optional[XsUri] = None,
+    ) -> None:
         if not name and not url:
             raise NoPropertiesProvidedException(
                 'Neither `name` nor `url` were provided - at least one must be provided.'
@@ -114,9 +118,15 @@ class IssueType:
         See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.4/xml/#type_issueType
     """
 
-    def __init__(self, *, type: IssueClassification, id: Optional[str] = None, name: Optional[str] = None,
-                 description: Optional[str] = None, source: Optional[IssueTypeSource] = None,
-                 references: Optional[Iterable[XsUri]] = None) -> None:
+    def __init__(
+        self, *,
+        type: IssueClassification,
+        id: Optional[str] = None,
+        name: Optional[str] = None,
+        description: Optional[str] = None,
+        source: Optional[IssueTypeSource] = None,
+        references: Optional[Iterable[XsUri]] = None,
+    ) -> None:
         self.type = type
         self.id = id
         self.name = name
