@@ -34,22 +34,30 @@ class ReleaseNotes:
         See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.4/#type_releaseNotesType
     """
 
-    def __init__(self, *, type: str, title: Optional[str] = None, featured_image: Optional[XsUri] = None,
-                 social_image: Optional[XsUri] = None, description: Optional[str] = None,
-                 timestamp: Optional[datetime] = None, aliases: Optional[Iterable[str]] = None,
-                 tags: Optional[Iterable[str]] = None, resolves: Optional[Iterable[IssueType]] = None,
-                 notes: Optional[Iterable[Note]] = None, properties: Optional[Iterable[Property]] = None) -> None:
+    def __init__(
+        self, *,
+        type: str, title: Optional[str] = None,
+        featured_image: Optional[XsUri] = None,
+        social_image: Optional[XsUri] = None,
+        description: Optional[str] = None,
+        timestamp: Optional[datetime] = None,
+        aliases: Optional[Iterable[str]] = None,
+        tags: Optional[Iterable[str]] = None,
+        resolves: Optional[Iterable[IssueType]] = None,
+        notes: Optional[Iterable[Note]] = None,
+        properties: Optional[Iterable[Property]] = None,
+    ) -> None:
         self.type = type
         self.title = title
         self.featured_image = featured_image
         self.social_image = social_image
         self.description = description
         self.timestamp = timestamp
-        self.aliases = aliases or []  # type: ignore
-        self.tags = tags or []  # type: ignore
-        self.resolves = resolves or []  # type: ignore
-        self.notes = notes or []  # type: ignore
-        self.properties = properties or []  # type: ignore
+        self.aliases = aliases or []  # type:ignore[assignment]
+        self.tags = tags or []  # type:ignore[assignment]
+        self.resolves = resolves or []  # type:ignore[assignment]
+        self.notes = notes or []  # type:ignore[assignment]
+        self.properties = properties or []  # type:ignore[assignment]
 
     @property
     @serializable.xml_sequence(1)
