@@ -15,26 +15,6 @@
 # SPDX-License-Identifier: Apache-2.0
 # Copyright (c) OWASP Foundation. All Rights Reserved.
 
-import re
-import warnings
-from datetime import datetime
-from decimal import Decimal
-from enum import Enum
-from typing import Any, Iterable, Optional, Tuple, Union
-
-import serializable
-from sortedcontainers import SortedSet
-
-from ..exception.model import MutuallyExclusivePropertiesException, NoPropertiesProvidedException
-from ..serialization import BomRefHelper
-from . import ComparableTuple, OrganizationalContact, OrganizationalEntity, Property, Tool, XsUri
-from .bom_ref import BomRef
-from .impact_analysis import (
-    ImpactAnalysisAffectedStatus,
-    ImpactAnalysisJustification,
-    ImpactAnalysisResponse,
-    ImpactAnalysisState,
-)
 
 """
 This set of classes represents the data that is possible about known Vulnerabilities.
@@ -49,6 +29,30 @@ Since CycloneDX schema version 1.4, this has become part of the core schema.
 """
 
 
+import re
+from datetime import datetime
+from decimal import Decimal
+from enum import Enum
+from typing import Any, Dict, FrozenSet, Iterable, Optional, Tuple, Type, Union
+
+import serializable
+from sortedcontainers import SortedSet
+
+from .._internal.compare import ComparableTuple as _ComparableTuple
+from ..exception.model import MutuallyExclusivePropertiesException, NoPropertiesProvidedException
+from ..schema.schema import SchemaVersion1Dot4, SchemaVersion1Dot5, SchemaVersion1Dot6
+from ..serialization import BomRefHelper
+from . import Property, Tool, XsUri
+from .bom_ref import BomRef
+from .contact import OrganizationalContact, OrganizationalEntity
+from .impact_analysis import (
+    ImpactAnalysisAffectedStatus,
+    ImpactAnalysisJustification,
+    ImpactAnalysisResponse,
+    ImpactAnalysisState,
+)
+
+
 @serializable.serializable_class
 class BomTargetVersionRange:
     """
@@ -60,8 +64,12 @@ class BomTargetVersionRange:
         See the CycloneDX schema: https://cyclonedx.org/docs/1.4/#type_vulnerabilityType
     """
 
-    def __init__(self, *, version: Optional[str] = None, range: Optional[str] = None,
-                 status: Optional[ImpactAnalysisAffectedStatus] = None) -> None:
+    def __init__(
+        self, *,
+        version: Optional[str] = None,
+        range: Optional[str] = None,
+        status: Optional[ImpactAnalysisAffectedStatus] = None,
+    ) -> None:
         if not version and not range:
             raise NoPropertiesProvidedException(
                 'One of version or range must be provided for BomTargetVersionRange - neither provided.'
@@ -122,8 +130,11 @@ class BomTargetVersionRange:
 
     def __lt__(self, other: Any) -> bool:
         if isinstance(other, BomTargetVersionRange):
-            return ComparableTuple((self.version, self.range, self.status)) < \
-                ComparableTuple((other.version, other.range, other.status))
+            return _ComparableTuple((
+                self.version, self.range, self.status
+            )) < _ComparableTuple((
+                other.version, other.range, other.status
+            ))
         return NotImplemented
 
     def __hash__(self) -> int:
@@ -147,9 +158,13 @@ class BomTarget:
         See the CycloneDX schema: https://cyclonedx.org/docs/1.4/#type_vulnerabilityType
     """
 
-    def __init__(self, *, ref: str, versions: Optional[Iterable[BomTargetVersionRange]] = None) -> None:
+    def __init__(
+        self, *,
+        ref: str,
+        versions: Optional[Iterable[BomTargetVersionRange]] = None,
+    ) -> None:
         self.ref = ref
-        self.versions = versions or []  # type: ignore
+        self.versions = versions or []  # type:ignore[assignment]
 
     @property
     @serializable.xml_sequence(1)
@@ -205,10 +220,13 @@ class VulnerabilityAnalysis:
         See the CycloneDX schema: https://cyclonedx.org/docs/1.4/#type_vulnerabilityType
     """
 
-    def __init__(self, *, state: Optional[ImpactAnalysisState] = None,
-                 justification: Optional[ImpactAnalysisJustification] = None,
-                 responses: Optional[Iterable[ImpactAnalysisResponse]] = None,
-                 detail: Optional[str] = None) -> None:
+    def __init__(
+        self, *,
+        state: Optional[ImpactAnalysisState] = None,
+        justification: Optional[ImpactAnalysisJustification] = None,
+        responses: Optional[Iterable[ImpactAnalysisResponse]] = None,
+        detail: Optional[str] = None,
+    ) -> None:
         if not state and not justification and not responses and not detail:
             raise NoPropertiesProvidedException(
                 'At least one of state, justification, responses or detail must be provided for VulnerabilityAnalysis '
@@ -216,7 +234,7 @@ class VulnerabilityAnalysis:
             )
         self.state = state
         self.justification = justification
-        self.responses = responses or []  # type: ignore
+        self.responses = responses or []  # type:ignore[assignment]
         self.detail = detail
 
     @property
@@ -285,6 +303,26 @@ class VulnerabilityAnalysis:
     def detail(self, detail: Optional[str]) -> None:
         self._detail = detail
 
+    # @property
+    # @serializable.view(SchemaVersion1Dot5)
+    # @serializable.xml_sequence(5)
+    # def first_issued(self) -> ...:
+    #     ...  # TODO since CDX 1.5
+    #
+    # @first_issued.setter
+    # def first_issued(self, ...) -> None:
+    #     ...  # TODO since CDX 1.5
+
+    # @property
+    # @serializable.view(SchemaVersion1Dot5)
+    # @serializable.xml_sequence(6)
+    # def last_updated(self) -> ...:
+    #     ...  # TODO since CDX 1.5
+    #
+    # @last_updated.setter
+    # def last_updated(self, ...) -> None:
+    #     ...  # TODO since CDX 1.5
+
     def __eq__(self, other: object) -> bool:
         if isinstance(other, VulnerabilityAnalysis):
             return hash(other) == hash(self)
@@ -306,7 +344,11 @@ class VulnerabilityAdvisory:
         See the CycloneDX schema: https://cyclonedx.org/docs/1.4/#type_advisoryType
     """
 
-    def __init__(self, *, url: XsUri, title: Optional[str] = None) -> None:
+    def __init__(
+        self, *,
+        url: XsUri,
+        title: Optional[str] = None,
+    ) -> None:
         self.title = title
         self.url = url
 
@@ -341,7 +383,11 @@ class VulnerabilityAdvisory:
 
     def __lt__(self, other: Any) -> bool:
         if isinstance(other, VulnerabilityAdvisory):
-            return ComparableTuple((self.title, self.url)) < ComparableTuple((other.title, other.url))
+            return _ComparableTuple((
+                self.title, self.url
+            )) < _ComparableTuple((
+                other.title, other.url
+            ))
         return NotImplemented
 
     def __hash__(self) -> int:
@@ -362,7 +408,11 @@ class VulnerabilitySource:
         See the CycloneDX schema: https://cyclonedx.org/docs/1.4/#type_vulnerabilitySourceType
     """
 
-    def __init__(self, *, name: Optional[str] = None, url: Optional[XsUri] = None) -> None:
+    def __init__(
+        self, *,
+        name: Optional[str] = None,
+        url: Optional[XsUri] = None,
+    ) -> None:
         if not name and not url:
             raise NoPropertiesProvidedException(
                 'Either name or url must be provided for a VulnerabilitySource - neither provided'
@@ -401,7 +451,11 @@ class VulnerabilitySource:
 
     def __lt__(self, other: Any) -> bool:
         if isinstance(other, VulnerabilitySource):
-            return ComparableTuple((self.name, self.url)) < ComparableTuple((other.name, other.url))
+            return _ComparableTuple((
+                self.name, self.url
+            )) < _ComparableTuple((
+                other.name, other.url
+            ))
         return NotImplemented
 
     def __hash__(self) -> int:
@@ -425,7 +479,11 @@ class VulnerabilityReference:
         See the CycloneDX schema: https://cyclonedx.org/docs/1.4/#type_vulnerabilityType
     """
 
-    def __init__(self, *, id: Optional[str] = None, source: Optional[VulnerabilitySource] = None) -> None:
+    def __init__(
+        self, *,
+        id: Optional[str] = None,
+        source: Optional[VulnerabilitySource] = None,
+    ) -> None:
         if not id and not source:
             raise NoPropertiesProvidedException(
                 'Either id or source must be provided for a VulnerabilityReference - neither provided'
@@ -464,7 +522,11 @@ class VulnerabilityReference:
 
     def __lt__(self, other: Any) -> bool:
         if isinstance(other, VulnerabilityReference):
-            return ComparableTuple((self.id, self.source)) < ComparableTuple((other.id, other.source))
+            return _ComparableTuple((
+                self.id, self.source
+            )) < _ComparableTuple((
+                other.id, other.source
+            ))
         return NotImplemented
 
     def __hash__(self) -> int:
@@ -474,18 +536,26 @@ class VulnerabilityReference:
         return f'<VulnerabilityReference id={self.id}, source={self.source}>'
 
 
+@serializable.serializable_enum
 class VulnerabilityScoreSource(str, Enum):
     """
     Enum object that defines the permissible source types for a Vulnerability's score.
 
     .. note::
         See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.4/#type_scoreSourceType
+
+    .. note::
+        No explicit carry-over from the former schema extension:
+         https://github.com/CycloneDX/specification/blob/master/schema/ext/vulnerability-1.0.xsd
     """
+    # see `_VulnerabilityScoreSourceSerializationHelper.__CASES` for view/case map
     CVSS_V2 = 'CVSSv2'
     CVSS_V3 = 'CVSSv3'
     CVSS_V3_1 = 'CVSSv31'
+    CVSS_V4 = 'CVSSv4'  # Only supported in >= 1.5
     OWASP = 'OWASP'  # Name change in 1.4
-    OPEN_FAIR = 'Open FAIR'  # Only < 1.4
+    SSVC = 'SSVC'  # Only supported in >= 1.5
+    # --
     OTHER = 'other'
 
     @staticmethod
@@ -541,9 +611,54 @@ class VulnerabilityScoreSource(str, Enum):
         """
         if self == VulnerabilityScoreSource.OWASP:
             return 'OWASP Risk'
-        return self.value  # type: ignore
+        return self.value  # type:ignore[no-any-return]
 
 
+class _VulnerabilityScoreSourceSerializationHelper(serializable.helpers.BaseHelper):
+    """  THIS CLASS IS NON-PUBLIC API  """
+
+    __CASES: Dict[Type[serializable.ViewType], FrozenSet[VulnerabilityScoreSource]] = dict()
+    __CASES[SchemaVersion1Dot4] = frozenset({
+        VulnerabilityScoreSource.CVSS_V2,
+        VulnerabilityScoreSource.CVSS_V3,
+        VulnerabilityScoreSource.CVSS_V3_1,
+        VulnerabilityScoreSource.OWASP,
+        VulnerabilityScoreSource.OTHER,
+    })
+    __CASES[SchemaVersion1Dot5] = __CASES[SchemaVersion1Dot4] | {
+        VulnerabilityScoreSource.CVSS_V4,
+        VulnerabilityScoreSource.SSVC
+    }
+    __CASES[SchemaVersion1Dot6] = __CASES[SchemaVersion1Dot5]
+
+    @classmethod
+    def __normalize(cls, vss: VulnerabilityScoreSource, view: Type[serializable.ViewType]) -> str:
+        return (
+            vss
+            if vss in cls.__CASES.get(view, ())
+            else VulnerabilityScoreSource.OTHER
+        ).value
+
+    @classmethod
+    def json_normalize(cls, o: Any, *,
+                       view: Optional[Type[serializable.ViewType]],
+                       **__: Any) -> str:
+        assert view is not None
+        return cls.__normalize(o, view)
+
+    @classmethod
+    def xml_normalize(cls, o: Any, *,
+                      view: Optional[Type[serializable.ViewType]],
+                      **__: Any) -> str:
+        assert view is not None
+        return cls.__normalize(o, view)
+
+    @classmethod
+    def deserialize(cls, o: Any) -> VulnerabilityScoreSource:
+        return VulnerabilityScoreSource(o)
+
+
+@serializable.serializable_enum
 class VulnerabilitySeverity(str, Enum):
     """
     Class that defines the permissible severities for a Vulnerability.
@@ -607,17 +722,20 @@ class VulnerabilityRating:
 
     .. warning::
         As part of implementing support for CycloneDX schema version 1.4, the three score types defined in the schema
-        externsion used prior to 1.4 have been deprecated. The deprecated `score_base` should loosely be equivalent to
+        extension used prior to 1.4 have been deprecated. The deprecated `score_base` should loosely be equivalent to
         the new `score` in 1.4 schema. Both `score_impact` and `score_exploitability` are deprecated and removed as
         they are redundant if you have the vector (the vector allows you to calculate the scores).
     """
 
-    def __init__(self, *, source: Optional[VulnerabilitySource] = None, score: Optional[Decimal] = None,
-                 severity: Optional[VulnerabilitySeverity] = None,
-                 method: Optional[VulnerabilityScoreSource] = None, vector: Optional[str] = None,
-                 justification: Optional[str] = None,
-                 # Deprecated parameters follow that are left to aid backwards compatability
-                 score_base: Optional[float] = None) -> None:
+    def __init__(
+        self, *,
+        source: Optional[VulnerabilitySource] = None,
+        score: Optional[Decimal] = None,
+        severity: Optional[VulnerabilitySeverity] = None,
+        method: Optional[VulnerabilityScoreSource] = None,
+        vector: Optional[str] = None,
+        justification: Optional[str] = None,
+    ) -> None:
         if not source and not score and not severity and not method and not vector and not justification:
             raise NoPropertiesProvidedException(
                 'At least one property must be provided when creating a VulnerabilityRating - none supplied.'
@@ -630,15 +748,6 @@ class VulnerabilityRating:
         self.vector = vector
         self.justification = justification
 
-        if score_base:
-            warnings.warn('`score_base` is deprecated - use `score`',
-                          category=DeprecationWarning, stacklevel=1)
-            if score:
-                warnings.warn('Both `score` and `score_base` supplied - the deprecated `score_base` will be discarded',
-                              category=DeprecationWarning, stacklevel=1)
-            else:
-                self.score = Decimal(score_base)
-
         if vector and method:
             self.vector = method.get_localised_vector(vector=vector)
 
@@ -680,6 +789,7 @@ class VulnerabilityRating:
         self._severity = severity
 
     @property
+    @serializable.type_mapping(_VulnerabilityScoreSourceSerializationHelper)
     @serializable.xml_sequence(4)
     def method(self) -> Optional[VulnerabilityScoreSource]:
         """
@@ -722,17 +832,15 @@ class VulnerabilityRating:
 
     def __lt__(self, other: Any) -> bool:
         if isinstance(other, VulnerabilityRating):
-            return ComparableTuple(
-                (self.severity, self.score, float(f'{self.score or 0:.1f}'), self.method, self.vector,
-                 self.justification)) < \
-                ComparableTuple(
-                    (other.severity, other.score, float(f'{other.score or 0:.1f}'), other.method, other.vector,
-                     other.justification))
+            return _ComparableTuple((
+                self.severity, self.score, self.score or 0, self.method, self.vector, self.justification
+            )) < _ComparableTuple((
+                other.severity, other.score, other.score or 0, other.method, other.vector, other.justification
+            ))
         return NotImplemented
 
     def __hash__(self) -> int:
-        return hash(
-            (self.source, float(f'{self.score or 0:.1f}'), self.severity, self.method, self.vector, self.justification))
+        return hash((self.source, self.score or 0, self.severity, self.method, self.vector, self.justification))
 
     def __repr__(self) -> str:
         return f'<VulnerabilityRating score={self.score}, source={self.source}>'
@@ -750,14 +858,17 @@ class VulnerabilityCredits:
         See the CycloneDX schema: https://cyclonedx.org/docs/1.4/#type_vulnerabilityType
     """
 
-    def __init__(self, *, organizations: Optional[Iterable[OrganizationalEntity]] = None,
-                 individuals: Optional[Iterable[OrganizationalContact]] = None) -> None:
+    def __init__(
+        self, *,
+        organizations: Optional[Iterable[OrganizationalEntity]] = None,
+        individuals: Optional[Iterable[OrganizationalContact]] = None,
+    ) -> None:
         if not organizations and not individuals:
             raise NoPropertiesProvidedException(
                 'One of `organizations` or `individuals` must be populated - neither were'
             )
-        self.organizations = organizations or []  # type: ignore
-        self.individuals = individuals or []  # type: ignore
+        self.organizations = organizations or []  # type:ignore[assignment]
+        self.individuals = individuals or []  # type:ignore[assignment]
 
     @property
     @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'organization')
@@ -820,53 +931,50 @@ class Vulnerability:
         See the CycloneDX schema: https://cyclonedx.org/docs/1.4/#type_vulnerabilityType
     """
 
-    def __init__(self, *, bom_ref: Optional[Union[str, BomRef]] = None, id: Optional[str] = None,
-                 source: Optional[VulnerabilitySource] = None,
-                 references: Optional[Iterable[VulnerabilityReference]] = None,
-                 ratings: Optional[Iterable[VulnerabilityRating]] = None, cwes: Optional[Iterable[int]] = None,
-                 description: Optional[str] = None, detail: Optional[str] = None, recommendation: Optional[str] = None,
-                 advisories: Optional[Iterable[VulnerabilityAdvisory]] = None, created: Optional[datetime] = None,
-                 published: Optional[datetime] = None, updated: Optional[datetime] = None,
-                 credits: Optional[VulnerabilityCredits] = None,
-                 tools: Optional[Iterable[Tool]] = None, analysis: Optional[VulnerabilityAnalysis] = None,
-                 affects: Optional[Iterable[BomTarget]] = None,
-                 properties: Optional[Iterable[Property]] = None,
-                 # Deprecated Parameters kept for backwards compatibility
-                 source_name: Optional[str] = None, source_url: Optional[str] = None,
-                 recommendations: Optional[Iterable[str]] = None) -> None:
+    def __init__(
+        self, *,
+        bom_ref: Optional[Union[str, BomRef]] = None,
+        id: Optional[str] = None,
+        source: Optional[VulnerabilitySource] = None,
+        references: Optional[Iterable[VulnerabilityReference]] = None,
+        ratings: Optional[Iterable[VulnerabilityRating]] = None,
+        cwes: Optional[Iterable[int]] = None,
+        description: Optional[str] = None,
+        detail: Optional[str] = None,
+        recommendation: Optional[str] = None,
+        workaround: Optional[str] = None,
+        advisories: Optional[Iterable[VulnerabilityAdvisory]] = None,
+        created: Optional[datetime] = None,
+        published: Optional[datetime] = None,
+        updated: Optional[datetime] = None,
+        credits: Optional[VulnerabilityCredits] = None,
+        tools: Optional[Iterable[Tool]] = None,
+        analysis: Optional[VulnerabilityAnalysis] = None,
+        affects: Optional[Iterable[BomTarget]] = None,
+        properties: Optional[Iterable[Property]] = None,
+    ) -> None:
         if isinstance(bom_ref, BomRef):
             self._bom_ref = bom_ref
         else:
             self._bom_ref = BomRef(value=str(bom_ref) if bom_ref else None)
         self.id = id
         self.source = source
-        self.references = references or []  # type: ignore
-        self.ratings = ratings or []  # type: ignore
-        self.cwes = cwes or []  # type: ignore
+        self.references = references or []  # type:ignore[assignment]
+        self.ratings = ratings or []  # type:ignore[assignment]
+        self.cwes = cwes or []  # type:ignore[assignment]
         self.description = description
         self.detail = detail
         self.recommendation = recommendation
-        self.advisories = advisories or []  # type: ignore
+        self.workaround = workaround
+        self.advisories = advisories or []  # type:ignore[assignment]
         self.created = created
         self.published = published
         self.updated = updated
         self.credits = credits
-        self.tools = tools or []  # type: ignore
+        self.tools = tools or []  # type:ignore[assignment]
         self.analysis = analysis
-        self.affects = affects or []  # type: ignore
-        self.properties = properties or []  # type: ignore
-
-        if source_name or source_url:
-            warnings.warn('`source_name` and `source_url` are deprecated - use `source`',
-                          category=DeprecationWarning, stacklevel=1)
-            if not source:
-                self.source = VulnerabilitySource(name=source_name, url=XsUri(source_url) if source_url else None)
-
-        if recommendations:
-            warnings.warn('`recommendations` is deprecated - use `recommendation`',
-                          category=DeprecationWarning, stacklevel=1)
-            if not recommendation:
-                self.recommendation = next(iter(recommendations))
+        self.affects = affects or []  # type:ignore[assignment]
+        self.properties = properties or []  # type:ignore[assignment]
 
     @property
     @serializable.json_name('bom-ref')
@@ -1015,8 +1123,36 @@ class Vulnerability:
         self._recommendation = recommendation
 
     @property
-    @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'advisory')
+    @serializable.view(SchemaVersion1Dot5)
+    @serializable.view(SchemaVersion1Dot6)
     @serializable.xml_sequence(9)
+    def workaround(self) -> Optional[str]:
+        """
+        A bypass, usually temporary, of the vulnerability that reduces its likelihood and/or impact.
+        Workarounds often involve changes to configuration or deployments.
+
+        Returns:
+            `str` if set else `None`
+        """
+        return self._workaround
+
+    @workaround.setter
+    def workaround(self, workaround: Optional[str]) -> None:
+        self._workaround = workaround
+
+    # @property
+    # @serializable.view(SchemaVersion1Dot5)
+    # @serializable.xml_sequence(10)
+    # def proof_of_concept(self) -> ...:
+    #     ...  # TODO since CDX 1.5
+    #
+    # @proof_of_concept.setter
+    # def proof_of_concept(self, ...) -> None:
+    #     ...  # TODO since CDX 1.5
+
+    @property
+    @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'advisory')
+    @serializable.xml_sequence(11)
     def advisories(self) -> 'SortedSet[VulnerabilityAdvisory]':
         """
         Advisories relating to the Vulnerability.
@@ -1032,7 +1168,7 @@ class Vulnerability:
 
     @property
     @serializable.type_mapping(serializable.helpers.XsdDateTime)
-    @serializable.xml_sequence(10)
+    @serializable.xml_sequence(12)
     def created(self) -> Optional[datetime]:
         """
         The date and time (timestamp) when the vulnerability record was created in the vulnerability database.
@@ -1048,7 +1184,7 @@ class Vulnerability:
 
     @property
     @serializable.type_mapping(serializable.helpers.XsdDateTime)
-    @serializable.xml_sequence(11)
+    @serializable.xml_sequence(13)
     def published(self) -> Optional[datetime]:
         """
         The date and time (timestamp) when the vulnerability record was first published.
@@ -1064,7 +1200,7 @@ class Vulnerability:
 
     @property
     @serializable.type_mapping(serializable.helpers.XsdDateTime)
-    @serializable.xml_sequence(12)
+    @serializable.xml_sequence(14)
     def updated(self) -> Optional[datetime]:
         """
         The date and time (timestamp) when the vulnerability record was last updated.
@@ -1078,8 +1214,18 @@ class Vulnerability:
     def updated(self, updated: Optional[datetime]) -> None:
         self._updated = updated
 
+    # @property
+    # @serializable.view(SchemaVersion1Dot5)
+    # @serializable.xml_sequence(15)
+    # def rejected(self) -> ...:
+    #     ...  # TODO since CDX 1.5
+    #
+    # @rejected.setter
+    # def rejected(self, ...) -> None:
+    #     ...  # TODO since CDX 1.5
+
     @property
-    @serializable.xml_sequence(13)
+    @serializable.xml_sequence(16)
     def credits(self) -> Optional[VulnerabilityCredits]:
         """
         Individuals or organizations credited with the discovery of the vulnerability.
@@ -1095,7 +1241,7 @@ class Vulnerability:
 
     @property
     @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'tool')
-    @serializable.xml_sequence(14)
+    @serializable.xml_sequence(17)
     def tools(self) -> 'SortedSet[Tool]':
         """
         The tool(s) used to identify, confirm, or score the vulnerability.
@@ -1110,7 +1256,7 @@ class Vulnerability:
         self._tools = SortedSet(tools)
 
     @property
-    @serializable.xml_sequence(15)
+    @serializable.xml_sequence(18)
     def analysis(self) -> Optional[VulnerabilityAnalysis]:
         """
         Analysis of the Vulnerability in your context.
@@ -1126,7 +1272,7 @@ class Vulnerability:
 
     @property
     @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'target')
-    @serializable.xml_sequence(16)
+    @serializable.xml_sequence(19)
     def affects(self) -> 'SortedSet[BomTarget]':
         """
         The components or services that are affected by the vulnerability.
@@ -1142,7 +1288,7 @@ class Vulnerability:
 
     @property
     @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'property')
-    @serializable.xml_sequence(17)
+    @serializable.xml_sequence(20)
     def properties(self) -> 'SortedSet[Property]':
         """
         Provides the ability to document properties in a key/value store. This provides flexibility to include data not
@@ -1164,17 +1310,18 @@ class Vulnerability:
 
     def __lt__(self, other: Any) -> bool:
         if isinstance(other, Vulnerability):
-            return ComparableTuple(
-                (self.id, self.description, self.detail, self.source, self.created, self.published)) < \
-                ComparableTuple(
-                    (other.id, other.description, other.detail, other.source, other.created, other.published))
+            return _ComparableTuple((
+                self.id, self.description, self.detail, self.source, self.created, self.published
+            )) < _ComparableTuple((
+                other.id, other.description, other.detail, other.source, other.created, other.published
+            ))
         return NotImplemented
 
     def __hash__(self) -> int:
         return hash((
             self.id, self.source, tuple(self.references), tuple(self.ratings), tuple(self.cwes), self.description,
-            self.detail, self.recommendation, tuple(self.advisories), self.created, self.published, self.updated,
-            self.credits, tuple(self.tools), self.analysis, tuple(self.affects), tuple(self.properties)
+            self.detail, self.recommendation, self.workaround, tuple(self.advisories), self.created, self.published,
+            self.updated, self.credits, tuple(self.tools), self.analysis, tuple(self.affects), tuple(self.properties)
         ))
 
     def __repr__(self) -> str:
